/* 
 * File:   config.h
 * Author: darran
 *
 * Created on October 29, 2009, 5:01 PM
 */

#ifndef _CONFIG_H
#define	_CONFIG_H

#ifdef	__cplusplus
extern "C" {
#endif

#define PACKAGE "gmtp"
#define PACKAGE_TITLE "gMTP"
#define PACKAGE_VERSION "0.7"


#ifdef	__cplusplus
}
#endif

#endif	/* _CONFIG_H */

